#
#   Tecnica definitiva per l'analisi delle reti.
#   Copyright (C) 2009 2010 2016  Alessandro Accattini
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#
##############################################################################
#
#   Calcola il guadagno di una rete generica fatta cosi':
#
#
# Net 1:
#
#         Z5
# Vin o---Z---+---o Vout
#             |
#             Z Z6
#             |
#            GND
#
#
#
#
# Net 2:
#
#         Z3      Z5
# Vin o---Z---+---Z---+---o Vout
#             |       |
#             Z Z4    Z Z6
#             |       |
#            GND     GND
#
#
#
#
# Net 3:
#
#         Z1      Z3      Z5
# Vin o---Z---+---Z---+---Z---+---o Vout
#             |       |       |
#             Z Z2    Z Z4    Z Z6
#             |       |       |
#            GND     GND     GND
#
#


set terminal png size 320,240 x000000 xffffff


# Variabili




# Funzioni

w(f)=2*pi*f
dB(v)=20*log10(v)

Zl(w,L)=w*L*{0,1}
Zc(w,C)=1/({0,1}*w*C)
Par(Z1,Z2)=Z1*Z2/(Z1+Z2)


Net_1(Z5,Z6)=Z6 / (Z5+Z6)
Net_2(Z3,Z4,Z5,Z6)=Z6 / (Par(Z4,Z5+Z6)+Z3) * Z4/(Z4+Z5+Z6)
Net_3(Z1,Z2,Z3,Z4,Z5,Z6)=Z6 / (Par(Par(Z4,Z5+Z6)+Z3,Z2)+Z1) * Z2/(Z2+Par(Z4,Z5+Z6)+Z3) * Z4/(Z4+Z5+Z6)


LowPass_1(w,R,C)=Net_1(R,Zc(w,C))
LowPass_2(w,R,C)=Net_2(R,Zc(w,C),R,Zc(w,C))
LowPass_3(w,R,C)=Net_3(R,Zc(w,C),R,Zc(w,C),R,Zc(w,C))




set grid x y
set grid mxtics mytics

set key on
set key title "lines"
set key Left reverse samplen 1 box lw 1
set key width 1 height 1
set key left
set key bottom

set samples 300

set logscale x

set xrange[0.1:100000]
set yrange[-60:10]

set xtics 10
set mxtics 10
set ytics 10
set mytics 3



set xlabel "Freq [Hz]"
set ylabel "Gain [dB]"
set title "RC low-pass filter analysis example"

plot	dB(abs(LowPass_1(w(x),10e3,100e-9))) axes x1y1 title "first order" lw 3, \
	dB(abs(LowPass_2(w(x),10e3,100e-9))) axes x1y1 title "second order" lw 3, \
	dB(abs(LowPass_3(w(x),10e3,100e-9))) axes x1y1 title "third order" lw 3


